package org.smartjava.scalatra

import org.scalatra.test.specs2._
import org.junit.runner.RunWith
import org.scalatra.test.Client
import org.specs2.SpecificationWithJUnit
import org.eclipse.jetty.util.log.Log

/**
 * Set of JUnit test to test our API
 */
class HelloScalatraServletSpec extends ScalatraSpec { 
  
    // add the servlet so we can start testing                                              					   
  addServlet(classOf[HelloScalatraServlet], "/*")
  
  // some constants
  val EXPECTED_BID = """{"id":345,"forItem":123,"minimum":20,"maximum":10,"currency":"GBP","bidder":"jdirksen","date":1347285103671}"""
  val BID_URL = "/users/jdirksen/bids/345";
  val MED_TYPE = "application/vnd.smartbid.bid+json"
  
  
  def is =
    "Calling an unknown url on the API "            ^
      "returns status 404"                           ! statusResult("/unknown",404)^
    												end ^ p ^
    "Calling a GET on " + BID_URL + " should"       ^
    "return status 200"                             ! statusResult(BID_URL,200)^
    "and body should equal: " + EXPECTED_BID        ! {get(BID_URL){response.body must_== EXPECTED_BID}}^
    "and media-type should equal: " + MED_TYPE		! {get(BID_URL){response.getContentType must startWith(MED_TYPE)}}
    												end
    												
  def statusResult(url:String,code:Int) = 
    get(url) {
	  status must_== code
  }
}